{% extends "admin/change_list.html" %}
{% load i18n admin_urls static%}

{% block object-tools-items %}    <li>
        <a href="{% url opts|admin_urlname:'import' %}" class="addlink ">
            {% trans 'Import from Community' %}
        </a>       
    {{ block.super }}
{% endblock %}










