# Generated by Django 4.0.3 on 2022-03-09 02:10

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="SharingConfigsConfig",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "api_endpoint",
                    models.URLField(
                        help_text="Path to API point",
                        max_length=250,
                        verbose_name="api_endpoint",
                    ),
                ),
                (
                    "api_key",
                    models.CharField(
                        help_text="API key for authorization",
                        max_length=128,
                        verbose_name="api_key",
                    ),
                ),
                (
                    "label",
                    models.CharField(
                        help_text="Label", max_length=50, verbose_name="label"
                    ),
                ),
                (
                    "default_organisation",
                    models.CharField(
                        blank=True,
                        help_text="Default organisation",
                        max_length=100,
                        verbose_name="default organisation",
                    ),
                ),
            ],
            options={
                "verbose_name": "Sharing configuration config",
            },
        ),
    ]
