{% extends "admin/change_form.html" %}
{% load i18n admin_urls static admin_modify %}


{% block object-tools-items %}
<li>  
  <a href="{% url opts|admin_urlname:'export' original.pk  %}" class="historylink">{% trans "Export to Community" %}</a>
</li>
  
{% endblock %}



